# Installation pre-requisites

TODO...

# RedHat Linux

For installation instructions specific to RedHat Linux please follow the steps
from [installation-redhat.md](installation-redhat.md)

# Windows

For installation instructions specific to Windows please follow the steps from
[installation-windows.md](installation-windows.md)


# Help with installation

If you encounter any issuse or have suggestions for improving the installation
instructions please send us an email at

bmi-developers [at] ad.ufl.edu 

We appreciate your feedback.
